# latest-earthquake-report-indonesia
This package inform the latest earthquake in Indonesia from BMKG | Meteorological, Climatological, and Geophysical Agency.

## How it work
This package informs earthquake that just occurred in Indonesia, sourced from BMKG.